@@ -24,12 +24,16 @@ class Code:
                        'detect', attempting to auto detect the type of
                        content. See :class:`purdy.parser.LexerContainer` for a
                        list of available lexers.
+
     :param lexer_holder: if lexer_name is "custom" this parameter is expected
                          to contain a purdy.parser.LexerHolder object.
+
+    :param palette: name of colourizer palette to use during colouring,
+                    defaults to 'code', which should handle most cases.
     """
 
     def __init__(self, filename='', text='', lexer_name='detect', 
-            lexer_holder=None):
+            purdy_lexer=None):
         self.source = ''
 
         if filename:
@@ -42,14 +46,13 @@ class Code:
 
         self.source = self.source.rstrip('\n')
 
-        from purdy.parser import LEXERS
+        from purdy.parser import PurdyLexer
         if lexer_name == 'detect':
-            self.lexer = LEXERS.detect_lexer(self.source)
+            self.lexer = PurdyLexer.factory_from_source(self.source)
         elif lexer_name == 'custom':
-            LEXERS.add_custom_lexer(lexer_holder)
-            self.lexer = lexer_holder.lexer
+            self.lexer = purdy_lexer
         else:
-            self.lexer = LEXERS.get_lexer(lexer_name)
+            self.lexer = PurdyLexer.factory_from_name(lexer_name)
 
     def remove_double_blanks(self, trim_whitespace=True):
         """Removes the second of two blanks in a row. If trim_whitespace is
@@ -71,6 +74,7 @@ class Code:
             previous = line
 
         self.source = '\n'.join(output)
+        return self
 
     def remove_lines(self, line_no, count=1):
         """Removes one or more lines from the source listing.
@@ -83,6 +87,7 @@ class Code:
         end = start + count
         del lines[start:end]
         self.source = '\n'.join(lines)
+        return self
 
     def replace_line(self, line_no, content):
         """Replaces the given line with new content
@@ -93,6 +98,7 @@ class Code:
         lines = self.source.split('\n')
         lines[line_no + 1] = content
         self.source = '\n'.join(lines)
+        return self
 
     def inline_replace(self, line_no, pos, content):
         """Replaces the contents of a line starting at pos with the new
@@ -106,6 +112,19 @@ class Code:
         lines[line_no + 1] = lines[line_no + 1][:pos - 1]
         lines[line_no + 1] += content
         self.source = '\n'.join(lines)
+        return self
+
+    def insert_line(self, line_no, content):
+        """Inserts the given line into the source, pushing the content down
+        from the given line number
+
+        :param line_no: number of the line to insert at, 1-indexed
+        :param content: content to insert
+        """
+        lines = self.source.split('\n')
+        lines.insert(line_no - 1, content)
+        self.source = '\n'.join(lines)
+        return self
 
     def _descend_ast(self, atok, parent, local_name, name_parts):
         for node in ast.iter_child_nodes(parent):
@@ -126,18 +145,6 @@ class Code:
 
         return ''
 
-    def insert_line(self, line_no, content):
-        """Inserts the given line into the source, pushing the content down
-        from the given line number
-
-        :param line_no: number of the line to insert at, 1-indexed
-        :param content: content to insert
-        """
-        lines = self.source.split('\n')
-        lines.insert(line_no - 1, content)
-        self.source = '\n'.join(lines)
-
-
     def python_portion(self, name):
         """Treates the source in this object as Python and then finds either
         the named function, class, or assigned variable and replaces the 
@@ -153,6 +160,7 @@ class Code:
         name_parts = name.split('.')
         self.source = self._descend_ast(atok, atok.tree, name_parts[0],
             name_parts[1:])
+        return self
 
     def left_justify(self):
         """Removes a consistent amount of leading whitespace from the front of
@@ -176,6 +184,29 @@ class Code:
                 output.append(line)
 
         self.source = '\n'.join(output)
+        return self
+
+    def fold_lines(self, start, end):
+        """Call this method to replace one or more lines with a vertical
+        elipses, i.e. a fold of the code. 
+
+        :param start: line number of the listing to start code folding on. 
+                      1-indexed.
+        :param end: line number to fold until, inclusive (1-indexed).
+        """
+        lines = self.source.split('\n')
+
+        self.source = '\n'.join(lines)
+
+        size = end - start + 1
+        lines[start - 1] = '⋮'
+
+        if size > 1:
+            del lines[start:end]
+
+        self.source = '\n'.join(lines)
+
+        return self
 
 # -----------------------------------------------------------------------------
 
@@ -219,21 +250,21 @@ class Listing:
                 for item in code:
                     self.append_code(item)
 
+
     def set_display(self, mode='plain', render_hook=None):
         """Code can be displayed using a variety of methods, from colourized
         text to the urwid TUI client. This method sets the options to control
         how rendering is done.
 
         :param mode: a key from :attr:`purdy.colour.COLOURIZERS` indicating
-                     which colourizer routine is used to coulour the source in
+                     which colourizer routine is used to colour the source in
                      this box. Defaults to 'plain'.
         :param render_hook: an optional hook the box calls when actions are
                             done on the box. Used by the TUI client so that
                             when something changes in the it is reflected in
                             the TUI.
         """
-        if mode:
-            self.colourizer = COLOURIZERS[mode]
+        self.colourizer = COLOURIZERS[mode]
 
         if render_hook:
             self.render_hook = render_hook
@@ -261,7 +292,8 @@ class Listing:
 
     def append_code(self, code):
         """Parses contents of a :class:`Code` object and appends it to this
-        box."""
+        box. Has a side effect of changing the listing's colour palette to
+        that of the code object sent in."""
         lines = parse_source(code.source, code.lexer)
         self.insert_lines(0, lines)
 
